//
//  SCITooltipModifierStyle.h
//  SciChart
//
//  Created by Admin on 15.12.15.
//  Copyright © 2015 SciChart Ltd. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "SCITooltipModifierStyleBase.h"

/**
 * @brief SCITooltipModifierStyle class.
 * @discussion Provides properties for styling the text and appearence of the TooltipMidifier.
 */
@interface SCITooltipModifierStyle : NSObject <SCITooltipModifierStyleBase>

/**
 * Changes appearance of targetMarker on the SCITooltipModifier.
 * <p>You can change style of point marker. Ensure that instance implements SCIPointMarker protocol!</p>
 * @code
 * SCIEllipsePointMarker *pointMarker = [SCIEllipsePointMarker new];
 * pointMarker.borderPen = [[SCIPenSolid alloc] initWithColor:[UIColor grayColor] Width:0.5f];
 * pointMarker.width = 10;
 * pointMarker.height = 10;
 * tooltipModifier.style.targetMarker = pointMarker;
 * @endcode
 * @see SCIPointMarker
 * @see SCIEllipsePointMarker
 * @see SCISpritePointMarker
 * @see SCISquarePointMarker
 * @see SCICrossPointMarker
 * @see SCITrianglePointMarker
 * @see SCICoreGraphicsPointMarker
 */
@property (nonatomic, strong) id<SCIPointMarker> targetMarker;

/**
 * Changes distance between targetMarker and toolTipView. Default is 5.0.
 */
@property (nonatomic) float alignmentMargin;

/**
 * Changes target offset mode of hit test. Default is SCITooltipTargetOffset_Up.
 * @see SCITooltipTargetOffsetMode
 */

@property (nonatomic) SCITooltipTargetOffsetMode targetOffsetMode;

/**
 * Changes colour mode of hit test. Default is SCITooltipColorMode_SeriesColorToDataView.
 * @see SCITooltipColorMode
 */
@property (nonatomic) SCITooltipColorMode colorMode;

/**
 * Changes style of head text in toolTipView.
 * @see SCITextFormattingStyle
 */
@property (nonatomic, copy) SCITextFormattingStyle * headLineStyle;

/**
 * Changes style of data text in toolTipView.
 * @see SCITextFormattingStyle
 */
@property (nonatomic, copy) SCITextFormattingStyle * dataStyle;

/**
 * Changes limit of size of toolTipView. Default is CGSizeMake(NaN, NaN) which means size is unlimited.
 */
@property (nonatomic) CGSize tooltipSize;

/**
 * StyleChanged - is block which always are called when any properties of SCITooltipModifierStyle is changed.
 * @see SCIActionBlock
 */
@property (nonatomic, copy) SCIActionBlock styleChanged;

/**
 * Changes aligment mode of toolTipView.
 * @see SCITooltipViewAlignmentMode
 */
@property (nonatomic) SCITooltipViewAlignmentMode tooltipAlignment;

/**
 * Changes background colour of toolTipView. Default is darkGrayColor. Ensure that property colorMode = SCITooltipColorMode_Default.
 * @see SCITooltipColorMode
 */
@property (nonatomic, strong) UIColor * tooltipColor;

/**
 * Changes border colour of toolTipView. Default is lightGrayColor. Ensure that property colorMode = SCITooltipColorMode_Default.
 * @see SCITooltipColorMode
 */
@property (nonatomic, strong) UIColor * tooltipBorderColor;

/**
 * Changes border width of toolTipView. Default is 2.0f.
 */
@property (nonatomic) float tooltipBorderWidth;

/**
 * Changes corner radius of toolTipView. Default is 0.0f.
 */
@property (nonatomic) float tooltipCornerRadius;

/**
 * Changes shadow offset of toolTipView. Default is CGSizeMake(-5, 10).
 */
@property (nonatomic) CGSize tooltipShadowOffset;

/**
 * Changes shadow radius of toolTipView. Default is 3.0f.
 */
@property (nonatomic) float tooltipShadowRadius;

/**
 * Changes shadow opacity of toolTipView. Default is 0.7f.
 */
@property (nonatomic) float tooltipShadowOpacity;

/**
 * Changes opacity of toolTipView. Default is 0.7f.
 */
@property (nonatomic) float tooltipOpacity;

/**
 * Changes mode of hitTest. Default is SCIHitTest_Default.
 */
@property (nonatomic) SCIHitTestMode hitTestMode;

/**
 * Changes number formatter for values. Default is nil.
 */
@property (nonatomic) NSNumberFormatter *numberFormatter;

/**
 * Changes date formatter for values. Default is nil.
 */
@property (nonatomic) NSDateFormatter *dateTimeFormatter;

@property (nonatomic) float targetOffsetValue;

@property (nonatomic) CGPoint targetCustomOffset;

@property (nonatomic) float contentPadding;

@property (nonatomic, copy) SCITooltipViewSetupBlock tooltipViewSetup;

@end
