//
//  DataManager.h
//  SciChartDemo
//
//  Created by Admin on 09.11.15.
//  Copyright © 2015 SciChart Ltd. All rights reserved.
//

#import <Foundation/Foundation.h>

@protocol SCIXyDataSeries;
@protocol SCIOhlcDataSeries;
@class SCDMultiPaneItem, SCIXyDataSeries;

typedef struct {
    float minRandMul;
    float minRandAdd;
    float maxRandMul;
    float maxRandAdd;
    
    float add;
    float addMul;
} DataManagerRandom;

typedef void(^XyDataFunction)(id<SCIXyDataSeries>,int);
typedef void(^OhlcDataFunction)(id<SCIOhlcDataSeries>,int);
typedef void(^OnNewData)(SCDMultiPaneItem *);

#define ARC4RANDOM_MAX 0x100000000

static inline int32_t randi(int32_t min, int32_t max) {
    return rand() % (max - min) + min;
}

static inline double randf(double min, double max) {
    return ((double)arc4random() / ARC4RANDOM_MAX) * (max - min) + min;
}



@interface DataManager : NSObject

+(void) loadPriceData:(id<SCIOhlcDataSeries>)data
             fileName:(NSString*) fileName
           isReversed:(BOOL) reversed
                count:(int) count;

+(void) loadXyData:(id<SCIXyDataSeries>)data
              From:(double)min
                To:(double)max
            Random:(DataManagerRandom)params;

+(void) loadXyData:(id<SCIXyDataSeries>)data
              From:(double)min
                To:(double)max
          Function:(XyDataFunction)func;

+(void) loadOhlcData:(id<SCIOhlcDataSeries>)data
                From:(double)min
                  To:(double)max
            Function:(OhlcDataFunction)func;

+(void) loadDataFromFile:(id<SCIXyDataSeries>) dataSeries
                fileName:(NSString*) fileName
              startIndex:(int) startIndex
               increment:(int) increment reverse:(BOOL)reverse;

+(void) loadDataFromFile:(id<SCIXyDataSeries>) dataSeries
                fileName:(NSString*) fileName;

+ (void)putDefaultDataMultiPaneIntoDataSeries:(id<SCIXyDataSeries>)dataSeries dataCount:(NSInteger)dataCount;

+ (SCIXyDataSeries *)getDampedSinewaveDataSeriesWithAmplitude:(double)amplitude
                                             andDampingfactor:(double)dampingFactor
                                                   pointCount:(int)pointCount
                                                         freq:(int)freq;

+ (NSArray<SCDMultiPaneItem *>*)loadPaneStockData;

@end

@interface SCDMultiPaneItem : NSObject

@property double open;
@property double high;
@property double low;
@property double close;
@property double volume;
@property NSDate *dateTime;

@end

@interface SCDMovingAverage : NSObject

@property double current;

- (instancetype)initWithLength:(int)length;
- (SCDMovingAverage*)push:(double)value;
- (void)update:(double)value;

@end

@interface SCDMcadPointItem : NSObject

@property double mcad;
@property double signal;
@property double divergence;

@end

@interface MarketDataService : NSObject

-(instancetype) initWithStartDate:(NSDate *)startDate
                 TimeFrameMinutes:(int) timeFrameMinutes
               TickTimerIntervals:(int) tickTimerIntervals;

-(NSMutableArray *) getHistoricalData:(int) numberBars;

-(SCDMultiPaneItem *) getNextBar;

@end

@interface RandomPriceDataSource : NSObject

@property (nonatomic, readonly) BOOL IsRunning;
@property (nonatomic) OnNewData updateData;
@property (nonatomic) OnNewData newData;

-(instancetype) initWithCandleIntervalMinutes:(int) candleIntervalMinutes
                              SimulateDateGap:(BOOL) simulateDateGap
                                 TimeInterval:(double) timeInterval
                              UpdatesPerPrice:(int) updatesPerPrice
                                   RandomSeed:(int) randomSeed
                                StartingPrice:(double) startingPrice
                                    StartDate:(NSDate *) startDate;

-(void) startGeneratePriceBars;
-(void) stopGeneratePriceBars;
-(SCDMultiPaneItem *) getNextData;
-(SCDMultiPaneItem *) getUpdateData;
-(SCDMultiPaneItem *) getNextRandomPriceBar;
-(NSDate *) emulateDateGap: (NSDate *) candleOpenTime;
-(void) onTimerElapsed;
-(void) clearEventHandlers;
-(SCDMultiPaneItem *) tick;

@end
