//
//  AnnotationsView.m
//  SciChartDemo
//
//  Created by Yaroslav Pelyukh on 3/29/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

#import "AnnotationsChartView.h"
#import <SciChart/SciChart.h>

@implementation AnnotationsChartView

@synthesize sciChartSurfaceView;
@synthesize surface;

-(void) setupAnnotations {
    // Box bound to chart surface
    SCIBoxAnnotation * boxBlue = [[SCIBoxAnnotation alloc] init];
    boxBlue.xAxisId = @"xAxis";
    boxBlue.yAxisId = @"yAxis";
    boxBlue.coordMode = SCIAnnotationCoord_Absolute;
    boxBlue.xStart = SCIGeneric(4);
    boxBlue.yStart = SCIGeneric(8);
    boxBlue.xEnd = SCIGeneric(7);
    boxBlue.yEnd = SCIGeneric(4);
    boxBlue.isEnabled = NO;
    boxBlue.style.fillBrush = [[SCIBrushSolid alloc] initWithColorCode:0x30FF7000];
    
    // Box bound to screen position
    SCIBoxAnnotation * boxRed = [[SCIBoxAnnotation alloc] init];
    boxRed.xAxisId = @"xAxis";
    boxRed.yAxisId = @"yAxis";
    boxRed.coordMode = SCIAnnotationCoord_Relative;
    boxRed.xStart = SCIGeneric(0.25);
    boxRed.yStart = SCIGeneric(0.25);
    boxRed.xEnd = SCIGeneric(0.5);
    boxRed.yEnd = SCIGeneric(0.5);
    boxRed.isEnabled = NO;
    boxRed.style.fillBrush = [[SCIBrushSolid alloc] initWithColorCode:0x301010FF];
    
    // line bound to position on screen
    SCILineAnnotation * lineAnnotationRelative = [[SCILineAnnotation alloc] init];
    lineAnnotationRelative.xAxisId = @"xAxis";
    lineAnnotationRelative.yAxisId = @"yAxis";
    lineAnnotationRelative.coordMode = SCIAnnotationCoord_Relative;
    lineAnnotationRelative.xStart = SCIGeneric(0.1);
    lineAnnotationRelative.yStart = SCIGeneric(0.1);
    lineAnnotationRelative.xEnd = SCIGeneric(0.9);
    lineAnnotationRelative.yEnd = SCIGeneric(0.1);
    lineAnnotationRelative.style.linePen = [[SCIPenSolid alloc] initWithColorCode:0xFF0000FF Width:2];
    
    // line bound to position on chart
    SCILineAnnotation * lineAnnotationAbsolute = [[SCILineAnnotation alloc] init];
    lineAnnotationAbsolute.xAxisId = @"xAxis";
    lineAnnotationAbsolute.yAxisId = @"yAxis";
    lineAnnotationAbsolute.coordMode = SCIAnnotationCoord_Absolute;
    lineAnnotationAbsolute.xStart = SCIGeneric(2);
    lineAnnotationAbsolute.yStart = SCIGeneric(2);
    lineAnnotationAbsolute.xEnd = SCIGeneric(5);
    lineAnnotationAbsolute.yEnd = SCIGeneric(6);
    lineAnnotationAbsolute.style.linePen = [[SCIPenSolid alloc] initWithColorCode:0xFF00FF00 Width:2];
    
    // line with X position bound to chart and Y to screen
    SCILineAnnotation * lineAnnotationAbsoluteX = [[SCILineAnnotation alloc] init];
    lineAnnotationAbsoluteX.xAxisId = @"xAxis";
    lineAnnotationAbsoluteX.yAxisId = @"yAxis";
    lineAnnotationAbsoluteX.coordMode = SCIAnnotationCoord_RelativeY;
    lineAnnotationAbsoluteX.xStart = SCIGeneric(1);
    lineAnnotationAbsoluteX.yStart = SCIGeneric(0.05);
    lineAnnotationAbsoluteX.xEnd = SCIGeneric(1);
    lineAnnotationAbsoluteX.yEnd = SCIGeneric(0.95);
    lineAnnotationAbsoluteX.style.linePen = [[SCIPenSolid alloc] initWithColorCode:0xFFFF0000 Width:2];
    
    // axis marker bound to chart surface
    SCIAxisMarkerAnnotation * xMarker = [[SCIAxisMarkerAnnotation alloc] init];
    xMarker.coordMode = SCIAnnotationCoord_Absolute;
    xMarker.xAxisId = @"xAxis";
    xMarker.position = SCIGeneric(2.5);
    xMarker.style.markerLinePen = [[SCIPenSolid alloc] initWithColorCode:0xAFFFFF00 Width:1];
    xMarker.style.backgroundColor = [UIColor fromColorCode:0xFFCFCF30];
    xMarker.style.textStyle.transform = CGAffineTransformMakeRotation(M_PI_2);
    
    // axis marker bound to screen
    SCIAxisMarkerAnnotation * yMarker = [[SCIAxisMarkerAnnotation alloc] init];
    yMarker.coordMode = SCIAnnotationCoord_Relative;
    yMarker.yAxisId = @"yAxis";
    yMarker.position = SCIGeneric(0.5);
    yMarker.style.markerLinePen = [[SCIPenSolid alloc] initWithColorCode:0xA00000FF Width:1];
    yMarker.style.backgroundColor = [UIColor fromColorCode:0xFF0000A0];
    yMarker.style.textStyle.fontSize = 14;
    yMarker.style.textStyle.fontName = @"Helvetica-Bold";
    yMarker.style.textStyle.color = [UIColor whiteColor];
    // axis marker annotation text is formated by axis as cursor text
    [surface.yAxes getAxisById:@"yAxis"].cursorTextFormatting = @"%.2f";
    
    SCITextAnnotation * textAnnotation = [[SCITextAnnotation alloc] init];
    textAnnotation.xAxisId = @"xAxis";
    textAnnotation.yAxisId = @"yAxis";
    textAnnotation.coordMode = SCIAnnotationCoord_Relative;
    textAnnotation.xPosition = SCIGeneric(0.7);
    textAnnotation.yPosition = SCIGeneric(0.5);
    textAnnotation.text = @"Red box: position bound to screen\n"
    "Blue box: position bound to chart surface\n"
    "Red line: bound to screen\n"
    "Green line: bound to surface\n"
    "Blue line: X bound to chart, Y bound to screen\n"
    "All annotations but axis markers are interactive";
    textAnnotation.style.textStyle.fontSize = 18;
    textAnnotation.style.textColor = [UIColor whiteColor];
    textAnnotation.style.backgroundColor = [UIColor clearColor];
    
    SCIAnnotationGroup * annotationGroup = [[SCIAnnotationGroup alloc]initWithChildAnnotations:@[boxBlue, boxRed,
                                                                                                 lineAnnotationRelative, lineAnnotationAbsolute, lineAnnotationAbsoluteX,
                                                                                                 textAnnotation,
                                                                                                 xMarker, yMarker]];
    [surface setAnnotation:annotationGroup];
}

-(instancetype)initWithFrame:(CGRect)frame{
    self = [super initWithFrame:frame];
    
    if (self) {
        SCIChartSurfaceView * view = [[SCIChartSurfaceView alloc]init];
        sciChartSurfaceView = view;
        
        [sciChartSurfaceView setTranslatesAutoresizingMaskIntoConstraints:NO];
        
        [self addSubview:sciChartSurfaceView];
        NSDictionary *layout = @{@"SciChart":sciChartSurfaceView};
        
        [self addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"|-(0)-[SciChart]-(0)-|" options:0 metrics:0 views:layout]];
        [self addConstraints:[NSLayoutConstraint constraintsWithVisualFormat:@"V:|-(0)-[SciChart]-(0)-|" options:0 metrics:0 views:layout]];
        
        [self initializeSurfaceData];
    }
    
    return self;
}

-(void) initializeSurfaceData{
    [surface free];
    surface = [[SCIChartSurface alloc] initWithView: sciChartSurfaceView];
    
    [[surface style] setBackgroundBrush: [[SCIBrushSolid alloc] initWithColorCode:0xFF1e1c1c]];
    [[surface style] setSeriesBackgroundBrush:[[SCIBrushSolid alloc] initWithColorCode:0xFF1e1c1c]];
    
    SCIPenSolid  *majorPen = [[SCIPenSolid alloc] initWithColorCode:0xFF393532 Width:0.6];
    SCIBrushSolid  *gridBandPen = [[SCIBrushSolid alloc] initWithColorCode:0xE1232120];
    SCIPenSolid  *minorPen = [[SCIPenSolid alloc] initWithColorCode:0xFF262423 Width:0.5];
    
    SCITextFormattingStyle *  textFormatting= [[SCITextFormattingStyle alloc] init];
    [textFormatting setFontSize:16];
    [textFormatting setFontName:@"Arial"];
    [textFormatting setColorCode:0xFFafb3b6];
    
    SCIAxisStyle * axisStyle = [[SCIAxisStyle alloc]init];
    [axisStyle setMajorTickBrush:majorPen];
    [axisStyle setGridBandBrush: gridBandPen];
    [axisStyle setMajorGridLineBrush:majorPen];
    [axisStyle setMinorTickBrush:minorPen];
    [axisStyle setMinorGridLineBrush:minorPen];
    [axisStyle setLabelStyle:textFormatting ];
    [axisStyle setDrawMinorGridLines:YES];
    [axisStyle setDrawMajorBands:YES];
    
    id<SCIAxis2D> axis = [[SCINumericAxis alloc] init];
    [axis setStyle: axisStyle];
    [axis setAxisId: @"yAxis"];
    [axis setGrowBy: [[SCIDoubleRange alloc]initWithMin:SCIGeneric(0.1) Max:SCIGeneric(0.1)]];
    [surface attachAxis:axis IsXAxis:NO];
    
    axis = [[SCINumericAxis alloc] init];
    [axis setAxisId: @"xAxis"];
    [axis setStyle: axisStyle];
    [axis setGrowBy: [[SCIDoubleRange alloc]initWithMin:SCIGeneric(0.1) Max:SCIGeneric(0.1)]];
    [surface attachAxis:axis IsXAxis:YES];
    
    SCIXAxisDragModifier * xDragModifier = [SCIXAxisDragModifier new];
    [xDragModifier setAxisId: @"xAxis"];
    [xDragModifier setDragMode: SCIAxisDragMode_Scale];
    [xDragModifier setClipModeX: SCIZoomPanClipMode_None];
    
    SCIYAxisDragModifier * yDragModifier = [SCIYAxisDragModifier new];
    [yDragModifier setAxisId: @"yAxis"];
    [yDragModifier setDragMode: SCIAxisDragMode_Pan];
    
    
    SCIPinchZoomModifier * pzm = [[SCIPinchZoomModifier alloc] init];
    SCIZoomExtentsModifier * zem = [[SCIZoomExtentsModifier alloc] init];
    SCIZoomPanModifier * zpm = [[SCIZoomPanModifier alloc] init];
    zpm.clipModeX = SCIZoomPanClipMode_None;
    
    [zpm setModifierName:@"PanZoom Modifier"];
    [zem setModifierName:@"ZoomExtents Modifier"];
    [pzm setModifierName:@"PinchZoom Modifier"];
    [yDragModifier setModifierName:@"YAxis Drag Modifier"];
    [xDragModifier setModifierName:@"XAxis Drag Modifier"];
    
    SCIModifierGroup * gm = [[SCIModifierGroup alloc] initWithChildModifiers:@[xDragModifier, yDragModifier, pzm, zem, zpm]];
    [surface setChartModifier: gm];
    
    [self setupAnnotations];
    
    [surface invalidateElement];
}
@end
