//
//  SCSColumnChartView.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/1/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import UIKit
import SciChart


class SCSColumnChartView: SCSBaseChartView {
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addAxis()
        addDataSeries()
    }
    
    // MARK: Private Functions
    
    private func addAxis() {
        
        let axisStyle = generateDefaultAxisStyle()
        
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultDateTimeAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId), isXAxis: false)
        
        addDefaultModifiers()
        
    }
    
    private func addDataSeries() {
        
        let brushColorsStart: [uint] = [0xFF4fd3a9, 0xFF3099fc, 0xFF3f3bd6]
        let brushColorsFinish: [uint] = [0xFF44b993, 0xFF287fd1, 0xFF3733bc]
        let penColors: [uint] = [0xFF232323, 0xFF232323, 0xFF232323]
        
        var i = 0
        while i < 3 {
            let brush = SCIBrushLinearGradient(colorCodeStart: brushColorsStart[i],
                                               finish: brushColorsFinish[i],
                                               direction: .Vertical)
            let pen = SCIPenSolid(colorCode: penColors[i], width: 0.4)
            chartSurface.attachRenderableSeries(getColumnRenderableSeries(brush, pen: pen, order: Int(i)))
            i = i + 1
        }
        chartSurface.invalidateElement()
        
    }
    
    private func getColumnRenderableSeries(fillBrush: SCIBrushLinearGradient, pen: SCIPenSolid, order: Int) -> SCIFastColumnRenderableSeries {
        
        let dataSeries = SCIXyDataSeries(XType: .DateTime, YType: .Float)
        
        
        DataManager.loadDataFromFile(dataSeries,
                                     fileName: "ColumnData",
                                     startIndex: Int32(order),
                                     increment: 3,
                                     reverse: false)
                
        let columnRenderableSeries = SCIFastColumnRenderableSeries()
        
        dataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        columnRenderableSeries.style.fillBrush = fillBrush
        columnRenderableSeries.style.borderPen = pen
        columnRenderableSeries.style.dataPointWidth = 0.3
        
        columnRenderableSeries.xAxisId = axisXId
        columnRenderableSeries.yAxisId = axisYId
        
        columnRenderableSeries.dataSeries = dataSeries
        columnRenderableSeries.hitTestProvider()
        
        return columnRenderableSeries
    }
    
    
    
}
