//
//  SCSLegendChartView.swift
//  SciChartSwiftDemo
//
//  Created by Hrybenuik Mykola on 8/23/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import SciChart
import UIKit

class SCSLegendChartView: SCSBaseChartView {
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addModifiers()
        addAxes()
        initializeSurfaceRenderableSeries()
    }
    
    private func addAxes() {
        let axisStyle = generateDefaultAxisStyle()
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId), isXAxis: false)
    }
    
    func addModifiers() {
        let legend = SCILegendCollectionModifier(position: [.Left, .Top], andOrientation: .Vertical)
        chartSurface.chartModifier = legend
    }
    
    func initializeSurfaceRenderableSeries() {
        self.attachRenderebleSeriesWithYValue(1000, andColor: UIColor.yellowColor(), seriesName: "Curve A", isVisible: true)
        self.attachRenderebleSeriesWithYValue(2000, andColor: UIColor.greenColor(), seriesName: "Curve B", isVisible: true)
        self.attachRenderebleSeriesWithYValue(3000, andColor: UIColor.redColor(), seriesName: "Curve C", isVisible: true)
        self.attachRenderebleSeriesWithYValue(4000, andColor: UIColor.blueColor(), seriesName: "Curve D", isVisible: false)
    }
    
    func attachRenderebleSeriesWithYValue(yValue: Double, andColor color: UIColor, seriesName: String, isVisible: Bool) {
        let dataCount = 10
        let dataSeries1 = SCIXyDataSeries(XType: .Float, YType: .Float)
        var y = yValue
        var i = 1
        while i <= dataCount {
            let x = i
            y = yValue + y
            dataSeries1.appendX(SCIGeneric(x), y: SCIGeneric(y))
            i += 1
        }
        dataSeries1.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        dataSeries1.seriesName = seriesName
        let renderableSeries1 = SCIFastLineRenderableSeries()
        renderableSeries1.style.linePen = SCIPenSolid(color: color, width: 0.7)
        renderableSeries1.xAxisId = "xAxis"
        renderableSeries1.yAxisId = "yAxis"
        renderableSeries1.dataSeries = dataSeries1
        renderableSeries1.isVisible = isVisible
        chartSurface.attachRenderableSeries(renderableSeries1)
        chartSurface.invalidateElement()
    }
    
}
