//
//  SCSScatterSpeedTestSciChart.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/29/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import UIKit
import SciChart

class SCSScatterSpeedTestSciChart: SCSBaseChartView, SpeedTest {
    
    let randomWalkGenerator = BrownianMotionGenerator()
    let dataSeries = SCIXyDataSeries(XType: .Double, YType: .Double)
    
    var delegate: DrawingProtocolDelegate!
    var chartProviderName: String! = "SciChart"
    var parameters: TestParameters!
    
    
    // MARK: SpeedTestProtocol
    
    func runTest(testParameters: TestParameters) {
        parameters = testParameters
        addSeries()
        chartSurface.invalidateElement()
        dataSeries.acceptUnsortedData = true
    }
    
    func updateChart() {
        delegate.chartExampleStarted!()

        var i: Int = 0
        while i < Int(dataSeries.count()) {
            
            let x = SCIGenericDouble(dataSeries.xValues().valueAt(i))
            let y = SCIGenericDouble(dataSeries.yValues().valueAt(i))
            let randX = randomize(-1.0, max: 1.0)
            let randY = randomize(-1.0, max: 1.0)
            dataSeries.updateAt(Int32(i),
                                XValue: SCIGeneric(x+randX),
                                YValue: SCIGeneric(y+randY))
            
            i += 1
        }
        
        
        chartSurface.invalidateElement()
    }
    
    func stopTest() {
        delegate.processCompleted!()
    }
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addAxes()
    }
    
    // MARK: Private Functions
    
    private func randomize(min: Double, max: Double) -> Double {
        return (Double(arc4random()) / 0x100000000) * (max - min) + min
    }
    
    private func addAxes() {
        
        let axisStyle = generateDefaultAxisStyle()
        
        let axisX = SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId);
        axisX.autoRange = .Once
        chartSurface.attachAxis(axisX, isXAxis: true)
        
        let axisY = SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId);
        axisY.visibleRange = SCIDoubleRange(min: SCIGeneric(-50), max: SCIGeneric(50))
        chartSurface.attachAxis(axisY, isXAxis: false)
        
        addDefaultModifiers()
        
    }
    
    private func addSeries() {
        
        dataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        let randomData: [NSArray] = NSArray.init(array: randomWalkGenerator.getXyData(parameters.PointCount, -50.0, 50.0)) as! [NSArray]
        
        var i: Int = 0
        while i < Int(parameters.PointCount) {
            
            let x = randomData[0][i].doubleValue
            let y = randomData[1][i].doubleValue
            
            dataSeries.appendX(SCIGeneric(x), y: SCIGeneric(y))
            
            i += 1
        }
        
        let renderSeries = SCIXyScatterRenderableSeries()
        renderSeries.dataSeries = dataSeries
        renderSeries.xAxisId = axisXId
        renderSeries.yAxisId = axisYId
        
        let ellipse = SCIEllipsePointMarker()
        ellipse.drawBorder = true
        ellipse.fillBrush = SCIBrushSolid(color: UIColor.blackColor())
        ellipse.borderPen = SCIPenSolid(color: UIColor.blueColor(), width: 0.5)
        ellipse.detalization = 10
        ellipse.height = 6.0
        ellipse.width = 6.0
        let marker = SCICoreGraphicsPointMarker()
        marker.height = 6.0
        marker.width = 6.0
        
        renderSeries.style.pointMarker = marker
        
        chartSurface.attachRenderableSeries(renderSeries)
        
    }
    
}

