//
//  SCSTooltipCustomizationChartView.swift
//  SciChartSwiftDemo
//
//  Created by Hrybenuik Mykola on 9/1/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import SciChart

class SCSTooltipCustomizationChartView: SCSBaseChartView {
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addModifiers()
        addAxes()
        initializeSurfaceRenderableSeries()
    }
    
    private func addAxes() {
        let axisStyle = generateDefaultAxisStyle()
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId), isXAxis: false)
    }
    
    func addModifiers() {
        let formatter = NSNumberFormatter()
        formatter.maximumFractionDigits = 1
        let customBlueColor = UIColor(red: 100.0 / 255.0, green: 149.0 / 255.0, blue: 237.0 / 255.0, alpha: 1.0)
        let customOrangeColor = UIColor(red: 226.0 / 255.0, green: 70.0 / 255.0, blue: 12.0 / 255.0, alpha: 1.0)
//        let customRedColor = UIColor(red: 255.0 / 255.0, green: 51.0 / 255.0, blue: 51.0 / 255.0, alpha: 1.0)
        let tooltipModifier = SCITooltipModifier()
        tooltipModifier.style.numberFormatter = formatter
        tooltipModifier.modifierName = "Tooltip modifier"
        tooltipModifier.style.tooltipSize = CGSizeMake(CGFloat.NaN, CGFloat.NaN)
        tooltipModifier.style.colorMode = .Default
        tooltipModifier.style.tooltipColor = customBlueColor
        tooltipModifier.style.tooltipOpacity = 0.8
        let textFormatting = SCITextFormattingStyle()
        textFormatting.fontSize = 14
        textFormatting.fontName = "Helvetica"
        textFormatting.color = UIColor.blackColor()
        tooltipModifier.style.dataStyle = textFormatting
        tooltipModifier.style.tooltipBorderWidth = 1
        tooltipModifier.style.tooltipBorderColor = customOrangeColor
        let pointMarker = SCIEllipsePointMarker()
        pointMarker.borderPen = SCIPenSolid(color: UIColor.grayColor(), width: 0.5)
        pointMarker.width = 10
        pointMarker.height = 10
        tooltipModifier.style.targetMarker = pointMarker
        chartSurface.chartModifier = tooltipModifier
    }

    
    func initializeSurfaceRenderableSeries() {
        self.attachRenderebleSeriesWithYValue(1000, andColor: UIColor(red: 100.0 / 255.0, green: 149.0 / 255.0, blue: 237.0 / 255.0, alpha: 1.0), seriesName: "Curve A", isVisible: true)
        self.attachRenderebleSeriesWithYValue(2000, andColor: UIColor(red: 226.0 / 255.0, green: 70.0 / 255.0, blue: 12.0 / 255.0, alpha: 1.0), seriesName: "Curve B", isVisible: true)
    }
    
    func attachRenderebleSeriesWithYValue(yValue: Double, andColor color: UIColor, seriesName: String, isVisible: Bool) {
        let dataCount = 500
        let dataSeries = SCIXyDataSeries(XType: .Float, YType: .Float)
        dataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        var yData = Double(arc4random_uniform(100))
        var i = 0
        while (i < dataCount) {
            let xData = SCIGeneric(i)
            let value = yData + randf(-5.0, 5.0)
            yData = value
            dataSeries.appendX(xData, y: SCIGeneric(value))
            i += 1
        }
        let rSeries = SCIFastLineRenderableSeries()
        rSeries.style.linePen = SCIPenSolid(color: color, width: 0.5)
        rSeries.xAxisId = "xAxis"
        rSeries.yAxisId = "yAxis"
        rSeries.dataSeries = dataSeries
        chartSurface.attachRenderableSeries(rSeries)
        chartSurface.invalidateElement()
    }
    
}
